part of modern_form_core;

Future<List<ModernFormBottomSheetProfileModel>?>
    showBottomSheetProfilesCheckBox(
  context, {
  List<ModernFormBottomSheetProfileModel>? list,
  List<ModernFormBottomSheetProfileModel>? initialValue,
  String? title,
  TextStyle? titleStyle,
  bool? forceMenu = false,
}) async {
  List<ModernFormBottomSheetProfileModel> selected = [];
  if (initialValue != null) {
    selected = List.from(initialValue);
  }

  if (forceMenu == null) {
    forceMenu = false;
  }

  if (MediaQuery.of(context).size.width > ModernFormUtils.webBreakdown ||
      forceMenu) {
    List<menu.PopupMenuEntry<dynamic>> items = [];

    list?.forEach((element) {
      items.add(menu.PopupMenuItem(
        value: element.returnValue,
        onTapEnabled: false,
        child: _ProfileItenCheckBox(
          image: element.imageUrl,
          imageWidth: 50,
          title: element.name,
          isSelected: selected.contains(element),
          onChanged: (value) {
            if (selected.contains(element)) {
              selected.remove(element);
            } else {
              selected.add(element);
            }
          },
        ),
      ));
    });
    if (items.isNotEmpty) {
      await menu.showMenu(
        context: context,
        position: menu.modernFormPopupMenuPosition(
            context, menu.ModernFormPopupMenuLocation.BottomLeft),
        items: items,
        maxHeight: MediaQuery.of(context).size.height * .3,
      );
    }
  } else {
    List<Widget> widgets = <Widget>[];

    list?.forEach(
      (element) => widgets.add(
        _ProfileItenCheckBox(
          image: element.imageUrl,
          title: element.name,
          isSelected: selected.contains(element),
          onChanged: (value) {
            if (selected.contains(element)) {
              selected.remove(element);
            } else {
              selected.add(element);
            }
          },
        ),
      ),
    );
    await showModalBottomSheet(
      isScrollControlled: true,
      context: context,
      builder: (context) {
        return ConstrainedBox(
          constraints: BoxConstraints(
              maxHeight: MediaQuery.of(context).size.height * .6),
          child: Column(
            mainAxisSize: MainAxisSize.min,
            children: <Widget>[
              ModernFormBottonSheetLabel(
                label: title,
                labelStyle: titleStyle,
              ),
              Expanded(
                child: ListView(
                  padding:
                      EdgeInsets.symmetric(vertical: ScreenUtil().setSp(15)),
                  shrinkWrap: true,
                  children: widgets,
                ),
              ),
            ],
          ),
        );
      },
    );
  }
  return selected;
}

class _ProfileItenCheckBox extends StatefulWidget {
  final String? image;
  final String? title;
  final bool isSelected;
  final void Function(bool)? onChanged;
  final double? imageWidth;

  const _ProfileItenCheckBox({
    Key? key,
    this.image,
    this.title,
    this.isSelected = false,
    this.onChanged,
    this.imageWidth,
  }) : super(key: key);

  @override
  _ProfileItenCheckBoxState createState() => _ProfileItenCheckBoxState();
}

class _ProfileItenCheckBoxState extends State<_ProfileItenCheckBox> {
  bool isSelected = false;
  @override
  void initState() {
    isSelected = widget.isSelected;
    super.initState();
  }

  void onTap() {
    setState(() {
      isSelected = !isSelected;
    });
    if (widget.onChanged != null) {
      widget.onChanged!(isSelected);
    }
  }

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Row(
        children: [
          Checkbox(
            value: isSelected,
            activeColor: Theme.of(context).primaryColor,
            onChanged: (value) {
              onTap();
            },
          ),
          Padding(
              padding: EdgeInsets.only(
                  bottom: ScreenUtil().setSp(13), left: ScreenUtil().setSp(10)),
              child: Row(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Container(
                    height: ScreenUtil().setHeight(50),
                    width: ScreenUtil().setWidth(widget.imageWidth ?? 90),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(6),
                      child: ImageWidget(
                        imageUrl: widget.image,
                        fit: BoxFit.cover,
                      ),
                    ),
                  ),
                  SizedBox(width: ScreenUtil().setSp(8)),
                  Text(
                    widget.title ?? "",
                    style: TextStyle(fontSize: ScreenUtil().setSp(15)),
                  ),
                ],
              )),
        ],
      ),
    );
  }
}
