part of modern_form_core;

class ModernFormLinksHelper {
  static Future<void> makePhoneCall(String number) async {
    if (kIsWeb) {
      Clipboard.setData(ClipboardData(text: number));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      String url = 'tel:$number';
      if (await canLaunch(url)) {
        await launch(url);
      }
    }
  }

  static Future<void> makeSendMail(String mail) async {
    if (kIsWeb) {
      Clipboard.setData(ClipboardData(text: mail));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      String url = 'mailto:$mail';
      if (await canLaunch(url)) {
        await launch(url);
      }
    }
  }

  static Future<void> shareText(String? text, {String? title}) async {
    if (kIsWeb) {
      await Clipboard.setData(ClipboardData(text: text));
      showFlushBar(value: true, textTrue: "Texto copiado");
    } else {
      await ModernFormShareHelper.text(text ?? "", subject: title);
    }
  }

  static Future<void> showShareType(
    BuildContext context, {
    Future<void> Function()? onShareUrl,
    Future<void> Function()? onShareArquive,
    Future<void> Function()? onDelete,
    menu.ModernFormPopupMenuLocation? menuLocation,
  }) async {
    List<ModernFormBottomSheetModel<int>> list = [
      ModernFormBottomSheetModel<int>(text: "Compartilhar URL", value: 0)
    ];
    if (!kIsWeb) {
      if (onShareArquive != null) {
        list.add(
          ModernFormBottomSheetModel<int>(
            text: "Compartilhar Arquivo",
            value: 1,
          ),
        );
      }

      if (onDelete != null) {
        list.add(
          ModernFormBottomSheetModel<int>(
            text: "Deletar arquivo do dispositivo",
            value: 2,
          ),
        );
      }
    }
    int? response = await showModernFormFilterPopupMenu<int>(
      context,
      forceMenu: true,
      menuLocation: menuLocation,
      list: list,
    );

    if (response != null) {
      switch (response) {
        case 0:
          if (onShareUrl != null) {
            await onShareUrl();
          }
          break;
        case 1:
          if (onShareArquive != null) {
            await onShareArquive();
          }
          break;
        case 2:
          if (onDelete != null) {
            await onDelete();
          }
          break;
        default:
          break;
      }
    }
  }
}
