part of modern_form_core;

class TimeRange {
  TimeOfDay? start;
  TimeOfDay? end;

  String get toElegantString {
    String text = "";

    if (start != null) {
      text += ModernFormUtils.timeFormat.format(start!.toDateTime);
      if (end != null && end != TimeOfDay(hour: 0, minute: 0)) {
        text += " - ";
        text += ModernFormUtils.timeFormat.format(end!.toDateTime);
      }
    }

    return text;
  }

  TimeRange({
    required this.start,
    required this.end,
  });

  TimeRange copyWith({
    TimeOfDay? start,
    TimeOfDay? end,
  }) {
    return TimeRange(
      start: start ?? this.start,
      end: end ?? this.end,
    );
  }

  Map<String, dynamic> toMap() {
    return {
      'start': start?.toMap(),
      'end': end?.toMap(),
    };
  }

  TimeRange.fromMap(Map<String, dynamic> map) {
    if (map['start'] != null) {
      start = ModernFormTimeOfDayExtension.fromMap(map['start']);
    }
    if (map['end'] != null) {
      end = ModernFormTimeOfDayExtension.fromMap(map['end']);
    }
  }

  @override
  String toString() => 'TimeRange(start: $start, end: $end)';

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is TimeRange && other.start == start && other.end == end;
  }

  @override
  int get hashCode => start.hashCode ^ end.hashCode;
}
