import 'dart:io';
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:get/state_manager.dart';
import '../../../../../../modern_form_files.dart';
import 'NetWorkImageDefault.dart';
import 'package:modern_form/modern_form_core.dart';

class CustomNetWorkImage extends StatelessWidget {
  final String? imageUrl;
  final BoxFit? fit;
  final bool? forceNetworkIfNotMemory;
  final double? width;
  final double? height;

  const CustomNetWorkImage({
    Key? key,
    this.imageUrl,
    this.fit,
    this.width,
    this.height,
    this.forceNetworkIfNotMemory,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (forceNetworkIfNotMemory != null && forceNetworkIfNotMemory!) {
      return NetWorkImageDefault(
        imageUrl: imageUrl,
        fit: fit,
        width: width,
        height: height,
      );
    } else {
      final controller = CustomNetWorkImageController(imageUrl);
      controller.init();

      return Obx(
        () {
          File file = controller.file;
          bool isFile = file.path != "";

          return controller.loading
              ? Center(child: ModernFormProgressIndicator())
              : (isFile
                  ? Image.file(
                      file,
                      fit: fit ?? BoxFit.cover,
                      width: width,
                      height: height,
                    )
                  : NetWorkImageDefault(
                      imageUrl: imageUrl,
                      fit: fit,
                      width: width,
                      height: height,
                    ));

          // return AnimatedCrossFade(
          //     crossFadeState: controller.loading
          //         ? CrossFadeState.showFirst
          //         : CrossFadeState.showSecond,
          //     duration: Duration(milliseconds: 200),
          //     firstChild: Center(child: ModernFormProgressIndicator()),
          //     alignment: Alignment.center,
          //     secondChild: isFile
          //         ? Center(
          //             child: Image.file(
          //               file,
          //               fit: fit ?? BoxFit.cover,
          //               width: width,
          //               height: height,
          //             ),
          //           )
          //         : NetWorkImageDefault(
          //             imageUrl: imageUrl,
          //             fit: fit,
          //             width: width,
          //             height: height,
          //           ),
          //   );
        },
      );
    }
  }
}

class CustomNetWorkImageController {
  final String? imageUrl;
  CustomNetWorkImageController(this.imageUrl);

  final _file = File("").obs;
  File get file => this._file.value;
  set file(File value) => this._file.value = value;

  final _loading = true.obs;
  bool get loading => this._loading.value;
  set loading(bool value) => this._loading.value = value;

  Future<void> init() async {
    String urlPath = ModernFormFileHelper.getUrlFormatedToFilepath(imageUrl!);
    String filePath = ModernFormFileHelper.filePath;
    if (filePath.isEmpty) {
      await ModernFormFileHelper.init();
      filePath = ModernFormFileHelper.filePath;
    }

    String path = "$filePath/$urlPath.png";

    File f = File(path);
    bool exist = f.existsSync();

    if (exist) {
      file = f;
      loading = false;
    } else {
      Uint8List? data =
          await (ModernFormDownloadHelper.simpleDownload(imageUrl));
      if (data != null) {
        await f.writeAsBytes(data);
        file = f;
      }

      loading = false;
    }
  }
}
