part of modern_form_core;

class ModernFormSearchWidget extends StatelessWidget
    implements PreferredSizeWidget {
  final TextEditingController controller;
  final FocusNode? focus;
  final Color? color;
  final void Function() onCancelSearch;
  final String hintText;
  final Function(String text)? onChanged;
  final void Function()? onClear;
  final Widget? child;

  ModernFormSearchWidget({
    required this.onCancelSearch,
    this.color,
    this.hintText = "",
    required this.controller,
    this.focus,
    this.onChanged,
    this.onClear,
    this.child,
  });

  @override
  Size get preferredSize => Size.fromHeight(56.0);

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      top: true,
      child: Material(
        elevation: 7,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: <Widget>[
            Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                _buildBackButton(),
                _buildTextField(),
                _buildClearButton(),
                child != null ? child! : Container()
              ],
            ),
          ],
        ),
      ),
    );
  }

  Widget _buildClearButton() {
    return IconButton(
      icon: Icon(
        Icons.close,
        color: color,
      ),
      onPressed: onClear,
    );
  }

  Widget _buildBackButton() {
    return IconButton(
      icon: Icon(Icons.arrow_back, color: color),
      onPressed: onCancelSearch,
    );
  }

  Widget _buildTextField() {
    return Expanded(
      child: Padding(
          padding: EdgeInsets.only(bottom: 8.0),
          child: TextField(
            controller: controller,
            focusNode: focus,
            autofocus: true,
            textInputAction: TextInputAction.search,
            decoration: InputDecoration(
              border: InputBorder.none,
              contentPadding: EdgeInsets.only(top: 12.0),
              hintText: hintText,
            ),
            textCapitalization: TextCapitalization.sentences,
            style: TextStyle(fontSize: 18.0),
            onChanged: onChanged,
          )),
    );
  }
}
