part of modern_form_core;

class ModernFormTextFieldsListenerView extends StatelessWidget {
  final ModernFormTextFieldsListenerViewModel? viewModel;

  const ModernFormTextFieldsListenerView(
    this.viewModel, {
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    if (viewModel == null) {
      return Container();
    }

    return Obx(
      () {
        bool validateEnabled = viewModel!.validateEnabled?.value ?? false;

        return ListView.builder(
          shrinkWrap: true,
          physics: NeverScrollableScrollPhysics(),
          itemCount: viewModel!.values.length,
          itemBuilder: (context, index) {
            ModernFormTextFieldListenner value = viewModel!.values[index];
            TextEditingController controller = viewModel!.controllers[index];
            FocusNode focus = viewModel!.focus[index];
            FocusNode? nextFocus;

            String? Function(dynamic)? validator;
            if (value.validator != null && validateEnabled) {
              validator = value.validator;
            }

            if ((viewModel!.focus.length - 1) > index) {
              nextFocus = viewModel!.focus[index + 1];
            }
            bool enabled = value.enabled ?? true;
            if (!enabled) {
              String text = controller.text;
              if (value.type == ModernFormTextFieldListennerType.Money) {
                text = ModernFormUtils.oCcy.format(value.value);
              }
              return ModernFormFakeTextField(
                label: "${value.label} ",
                enabled: enabled,
                initialValue: text,
                prefixIcon: value.prefixIcon,
                validator: validator,
              );
            }

            Widget child = ModernFormTextField(
              label: "${value.label} ",
              controller: controller,
              enabled: enabled,
              focus: focus,
              helperText: value.helperText,
              helperStyle: value.helperStyle,
              nextFocus: nextFocus,
              keyboardType: value.keyboardType ?? value.type?.toKeyboardType,
              textInputAction: value.textInputAction,
              textCapitalization: value.textCapitalization,
              validator: validator,
              prefixIcon: value.prefixIcon,
              decoration: value.decoration,
            );

            if (value.padding != null) {
              child = Padding(
                padding: value.padding!,
                child: child,
              );
            }

            return child;
          },
        );
      },
    );
  }
}
