part of modern_form_files;

extension ModernFormFileStringExtension on String {
  String get getExtensionFromUrl {
    String extensionType = "";
    int index = this.lastIndexOf('.');
    if (index != -1) {
      extensionType = this.substring(index, this.length);
      int indexQuery = extensionType.indexOf("?");
      if (indexQuery != -1) {
        extensionType = extensionType.substring(1, indexQuery);
      }
    }

    return extensionType;
  }

  Future<String> toDevicePath(String type) =>
      ModernFormFileHelper.getFilePathFromUrl(this, type);

  Future<bool> isSaveinDeviceFromPath() async {
    try {
      if (kIsWeb) {
        return false;
      }

      File file = File(this);
      return file.exists();
    } catch (e) {
      print("ERROR isSaveinDeviceFromPath() --> $e");
      return false;
    }
  }

  Future<bool> isSaveinDeviceFromUrl(String? type) async {
    try {
      if (kIsWeb) {
        return false;
      }

      String path = await ModernFormFileHelper.getFilePathFromUrl(this, type!);
      File file = File(path);
      return file.exists();
    } catch (e) {
      print("ERROR isSaveinDevice() --> $e");
      return false;
    }
  }

  Future<Uint8List?> get toUint8ListFromPath async {
    if (this.isNotEmpty) {
      File file = File(this);
      bool exist = await file.exists();
      if (exist) {
        Uint8List data = await file.readAsBytes();

        return data;
      } else {
        return null;
      }
    }
    return null;
  }

  Future<Uint8List?> get toUint8ListFromUrl async {
    if (this.isNotEmpty) {
      File file = File(this);
      bool exist = await file.exists();
      if (exist) {
        Uint8List data = await file.readAsBytes();

        return data;
      } else {
        return null;
      }
    }
    return null;
  }
}

extension ModernFormFileWriteStatic on File {
  static Future<File?> writeAsBytes(String path, Uint8List data) async {
    try {
      File file = File(path);
      file = await file.writeAsBytes(data);
      return file;
    } catch (e) {
      return null;
    }
  }
}

extension ModernFormUint8ListToFileEntity on Uint8List {
  Future<String> saveToFile(String url, String type) async {
    if (this.isNotEmpty) {
      String path = await ModernFormFileHelper.getFilePathFromUrl(url, type);
      bool exist = await url.isSaveinDeviceFromUrl(type);
      if (!exist) {
        await ModernFormFileWriteStatic.writeAsBytes(path, this);
      }
      return path;
    } else {
      return "";
    }
  }
}
