import 'dart:io';
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:modern_form/modern_form_core.dart';
import 'package:modern_form/modern_form_files.dart';
import 'package:rxdart/rxdart.dart';
import 'package:youtube_explode_dart/youtube_explode_dart.dart';

class ModernFormVideoPlatformHelper {
  static Future<void> shareVideo(Uint8List bytes, String? text,
      {String? title}) async {
    await ModernFormShareHelper.file(
      title ?? '',
      'video.mp4',
      bytes.toList(),
      'video/mp4/mp3',
      text: text ?? "",
    );
  }

  static Future<Uint8List?> downloadFromYoutube(String url,
      [void Function(int, int)? onBytesReceived, bool? force]) async {
    String filePath = await ModernFormFileHelper.getFilePathFromUrl(url, "mp4");
    File file = File(filePath);
    try {
      ModernFormProgressDialog progressDialog = ModernFormProgressDialog();
      // var stream = BehaviorSubject<double>.seeded(0);

      if (onBytesReceived == null) {
        progressDialog.showProgressDialog(
          textToBeDisplayed: 'Fazendo download do vídeo...',
          progressColor: Colors.white,
          barrierColor: Color(0x88222222),
        );
      }

      bool exists = await file.exists();
      bool isForce = force != null && force;
      if (isForce && exists) {
        await file.delete();
      }
      if (!exists || isForce) {
        // print("init");
        YoutubeExplode yt = YoutubeExplode();
        Video video = await yt.videos.get(url);
        // print(" yt.videos.get");

        StreamManifest manifest =
            await yt.videos.streamsClient.getManifest(video.id);

        // print("manifest");
        int length = manifest.muxed.length;
        // print(
        // "manifest.muxed.toList() --> ${manifest?.muxed?.toList()?.length}");
        MuxedStreamInfo streamInfo = length > 1
            ? manifest.muxed.toList()[length - 1]
            : manifest.muxed.toList()[0];

        Stream<List<int>> ytStream =
            yt.videos.streamsClient.get(streamInfo).asBroadcastStream();

        // var streamConsumer = BehaviorSubject<List<int>>.seeded(<int>[]);

        // // Pipe all the content of the stream into the file.
        // await ytStream.pipe(streamConsumer);

        // // Close the file.
        // await streamConsumer.close();
        // await stream.close();

        final controller = new BehaviorSubject<List<int>>();
        if (onBytesReceived != null) {
          controller.addStream(ytStream);

          print("aoakosakso-");

          controller.listen((event) {
            onBytesReceived(streamInfo.size.totalBytes, file.lengthSync());
          });
        }

        // Open a file for writing.
        IOSink fileStream = file.openWrite();

        // Pipe all the content of the stream into the file.
        await ytStream.pipe(fileStream);

        // Close the file.
        await fileStream.flush();
        await fileStream.close();

        controller.close();
        yt.close();
      }

      Uint8List data = await file.readAsBytes();
      if (onBytesReceived == null) {
        progressDialog.dismissProgressDialog();
      }
      return data;
    } catch (e) {
      try {
        await file.delete();
      } catch (e) {
        print("ERROR downloadVideoFromYoutube file.delete() --> $e");
      }
      print("ERROR downloadVideoFromYoutube: $url --> $e");
      return null;
    }
  }
}
