import 'dart:io';
import 'dart:typed_data';
import 'package:flick_video_player/flick_video_player.dart';
import 'package:flutter/foundation.dart';
import 'package:modern_form/modern_form_core.dart';
import 'package:modern_form/modern_form_videos.dart';
import 'package:video_player/video_player.dart';

class ModernFormViewVideoPlatformHelper {
  static FlickManager flickManager(
      String? url, String? path, void Function()? onError) {
    late FlickManager flickManager;

    if (path != null && path.isNotEmpty) {
      File file = File(path);
      bool exist = file.existsSync();
      if (exist) {
        VideoPlayerController vC = VideoPlayerController.file(file);
        vC.addListener(() {
          bool isError = flickManager.flickVideoManager!.errorInVideo;

          if (isError && onError != null) {
            onError();
          }
          debugPrint(
              "flickManager.flickVideoManager.errorInVideo --> ${flickManager.flickVideoManager!.errorInVideo}");
        });
        flickManager = FlickManager(
          videoPlayerController: vC,
          autoPlay: false,
        );
      } else {
        flickManager = FlickManager(
          videoPlayerController: VideoPlayerController.network(url!),
          autoPlay: false,
        );
        if (onError != null) {
          onError();
        }
      }
    } else {
      flickManager = FlickManager(
        videoPlayerController: VideoPlayerController.network(url!),
        autoPlay: false,
      );
      if (onError != null) {
        onError();
      }
    }

    return flickManager;
  }

  static void shareUrl(String? url) async {
    ModernFormLinksHelper.shareText(url);
  }

  static void shareArquive(String? path, String? url) async {
    File? file = path != null && path.isNotEmpty ? File(path) : null;
    bool exist = file?.existsSync() ?? false;
    bool isArquive = path != null && path.isNotEmpty && exist;

    if (isArquive) {
      Uint8List bytes = file!.readAsBytesSync();
      ModernFormVideoHelper.shareVideo(bytes, "");
    } else if (url != null) {
      ModernFormVideoHelper.shareVideoFromUrl(url, "");
    }
  }

  static Future<void> downloadArquive(String url) async {
    await ModernFormVideoHelper.downloadWithProgress(url);
  }

  static Future<void> deleteArquive(String path) async {
    try {
      File file = File(path);
      bool exist = await file.exists();
      if (exist) {
        await file.delete();
      }
    } catch (e) {
      print("ERROR deleteArquive() --> $e");
    }
  }
}
