part of modern_form_videos;

class ModernFormViewVideo extends StatefulWidget {
  final ModernFormViewVideosModel data;

  const ModernFormViewVideo(
    this.data, {
    Key? key,
  }) : super(key: key);

  @override
  _ModernFormViewVideoState createState() => _ModernFormViewVideoState();
}

class _ModernFormViewVideoState extends State<ModernFormViewVideo> {
  void Function(BuildContext)? share;
  bool isError = false;

  FlickManager? flickManager;
  Widget? child;

  @override
  void initState() {
    share = _share(widget.data);

    flickManager = ModernFormViewVideoHelper.flickManager(
      widget.data.url,
      widget.data.path,
      onError,
    );

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    String? videoPath = widget.data.path;
    String? videoUrl = widget.data.url;

    bool isYoutube = videoPath == null &&
        videoUrl != null &&
        (videoUrl.contains('youtube') || videoUrl.contains('youtu.be'));

    if (isYoutube) {
      child = ModernFormYoutubeViewPlayer(url: videoUrl, share: share);
    } else if (!isError) {
      child = ModernFormVideoPlayer(flickManager: flickManager, share: share);
    }

    return child ?? SizedBox();
  }

  void onError() {
    String? videoPath = widget.data.path;
    String? videoUrl = widget.data.url;

    child = Row(
      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
      children: [
        ElevatedButton(
          child: Text(
            "Fazer download",
            style: TextStyle(color: Colors.white),
          ),
          style: ElevatedButton.styleFrom(
            primary: ModernFormUtils.primaryColor,
          ),
          onPressed: () async {
            if (widget.data.onDownloadVideoCallback != null) {
              widget.data.onDownloadVideoCallback!();
            }

            await ModernFormViewVideoHelper.downloadArquive(videoUrl!);
            setState(() {
              flickManager = ModernFormViewVideoHelper.flickManager(
                videoUrl,
                videoPath,
                onError,
              );
            });
            showFlushBar(value: true, textTrue: "Atualize a página!!");
          },
        ),
        ElevatedButton(
          child: Text(
            "Abrir vídeo",
            style: TextStyle(color: Colors.white),
          ),
          style: ElevatedButton.styleFrom(
            primary: ModernFormUtils.secundaryColor,
          ),
          onPressed: () {
            if (widget.data.onOpenVideoCallback != null) {
              widget.data.onOpenVideoCallback!();
            }

            launch(videoUrl!);
          },
        ),
      ],
    );
    if (!isError) {
      setState(() {
        isError = true;
      });
    }
  }
}

void Function(BuildContext) _share(ModernFormViewVideosModel data) {
  return (BuildContext context) {
    ModernFormLinksHelper.showShareType(
      context,
      onShareUrl: () async {
        if (data.onShareVideoUrlCallback != null) {
          data.onShareVideoUrlCallback!();
        }

        ModernFormViewVideoHelper.shareUrl(data.url);
      },
      onShareArquive: data.shareArquiveEnabled == false
          ? null
          : () async {
              if (data.onShareVideoArquiveCallback != null) {
                data.onShareVideoArquiveCallback!();
              }

              ModernFormViewVideoHelper.shareArquive(data.path!, data.url);
            },
      onDelete: () async {
        dialogDelete(
          () async {
            if (data.onDeleteVideoFromDevice != null) {
              data.onDeleteVideoFromDevice!();
            }

            await ModernFormViewVideoHelper.deleteArquive(data.path!);
            showFlushBar(value: true, textTrue: "Atualize a página!!");
          },
          "arquivo",
        );
      },
      menuLocation: ModernFormPopupMenuLocation.BottomRight,
    );
  };
}
